@@ -196,6 +196,7 @@ static void params_free(params_t *param)
     free(param->input);
     free(param->output);
     free(param->summary.file);
+    free(param);
     param = NULL;
 }
 
@@ -442,6 +443,11 @@ int main(int argc, char **pp_argv)
         usage();
 
     param = params_init();
+    if (param == NULL)
+    {
+        printf("dvbinfo: out of memory\n");
+        exit(EXIT_FAILURE);
+    }
     capture.params = param;
     capture.fifo = fifo_new();
     capture.empty = fifo_new();
@@ -706,6 +712,7 @@ int main(int argc, char **pp_argv)
         closelog();
 #endif
     params_free(param);
+    param = NULL;
 
     if (err < 0)
         exit(EXIT_FAILURE);
